==> v6.0-b2.tar.gz: ffmpeg-builds/README.md <==
FFmpeg builds for GNU/Linux & Windows
=====================================

### FFmpeg 6.0 Builds2:

  * **`GNU/Linux downloads (Static):`**
  
    * [ffmpeg-6.0-linux-gnu-64bit-build2.tar.bz2](https://drive.proton.me/urls/87E226C29C#mcuvbx0p6DLy) (Generic Linux x86_64)
    * [ffmpeg-6.0-linux-gnu-64bit-build2.deb](https://drive.proton.me/urls/87E226C29C#mcuvbx0p6DLy) (Debian/Ubuntu x86_64)
    * [ffmpeg-6.0-linux-gnu-64bit-build2.rpm](https://drive.proton.me/urls/87E226C29C#mcuvbx0p6DLy) (RedHat/Fedora x86_64)
       
  * **`Windows downloads (Shared):`**
  
    * [ffmpeg-6.0-win-64bit-build2.zip](https://drive.proton.me/urls/87E226C29C#mcuvbx0p6DLy)
    * [ffmpeg-6.0-win-64bit-build2.exe](https://drive.proton.me/urls/87E226C29C#mcuvbx0p6DLy)
    * [ffmpeg-6.0-cygwin-64bit-build2.tar.gz](https://drive.proton.me/urls/87E226C29C#mcuvbx0p6DLy)

### HOW TO INSTALL:

  * **GNU/Linux instructions:**

    * Download the package [ffmpeg-6.0-linux-gnu-64bit-build2.tar.bz2](https://drive.proton.me/urls/87E226C29C#mcuvbx0p6DLy).
    * Open the terminal and type the following command for install:
        * `$ sudo tar jxvf ffmpeg-6.0-linux-gnu-64bit-build2.tar.bz2 -C /`
    
  * **Windows instructions:**
    
    * Download the package [ffmpeg-6.0-win-64bit-build2.zip](https://drive.proton.me/urls/87E226C29C#mcuvbx0p6DLy).
    * Unzip the package with [7-zip](http://www.7-zip.org/) or [Winrar](http://www.rarlab.com/).
    * Copy the files to a folder. For example: `C:\Program Files\FFmpeg`
    * Add the path `C:\Program Files\FFmpeg` to [PATH](https://www.google.es/search?q=add+folder+to+PATH+on+Windows) variable.

  * **Cygwin instructions:**
    
    * Download the package [ffmpeg-6.0-cygwin-64bit-build2.tar.gz](https://drive.proton.me/urls/87E226C29C#mcuvbx0p6DLy).
    * Open the Cygwin terminal and type the following command for install:
        * `$ sudo tar jxvf ffmpeg-6.0-cygwin-64bit-build2.tar.gz -C /`   
 
### HOW TO CREATE YOUR BUILD:

  * **GNU/Linux instructions:**
  
    * Install dependencies in your GNU/Linux distro.
    * Dependencies: `wget`, `gcc`, `make`, `cmake`, `meson/ninja` and `git`.
    * Type the following commands:
        * `$ git clone https://gitlab.com/q3aql/ffmpeg-builds`
        * `$ cd ffmpeg-builds`
        * `$ sudo ./ffmpeg-static-build-[arch].sh`
    
    _Note: Replace `[arch]` with `linux32` or `linux64` depending on your architecture._
      
  * **Windows instructions:**
  
    * Install Cygwin for [32bits](https://cygwin.com/setup-x86.exe) or [64bits](https://cygwin.com/setup-x86_64.exe).
    * During installation, `configure the repository` and install `git` and `wget` or `lynx`.
    * Open Cygwin terminal and type the following commands:
        * `$ git clone https://gitlab.com/q3aql/ffmpeg-builds`
        * `$ cd ffmpeg-builds`
        * `$ ./ffmpeg-share-build-[arch].sh`
    
    _Note: Replace `[arch]` with `cygwin32` or `cygwin64` depending on your architecture._

### Related links:

  * [FFmpeg homepage](https://ffmpeg.org/)
  * [FFmpeg Linux builds by John](https://johnvansickle.com/ffmpeg/)
  * [FFmpeg Win64/Linux64 Builds by Btbn](https://github.com/BtbN/FFmpeg-Builds)
  * [FFmpeg Win32 Builds](https://github.com/sudo-nautilus/FFmpeg-Builds-Win32)

==> 6.1.tar.gz: ffmpeg-builds/README.md <==
FFmpeg builds for GNU/Linux & Windows
=====================================

### FFmpeg 6.1 Builds:

  * **`GNU/Linux downloads (Static):`**
  
    * [ffmpeg-6.1-linux-gnu-64bit-build.tar.bz2](https://drive.proton.me/urls/FZH7FV29FR#5FuAfSzxhH6h) (Generic Linux x86_64)
    * [ffmpeg-6.1-linux-gnu-64bit-build.deb](https://drive.proton.me/urls/FZH7FV29FR#5FuAfSzxhH6h) (Debian/Ubuntu x86_64)
    * [ffmpeg-6.1-linux-gnu-64bit-build.rpm](https://drive.proton.me/urls/FZH7FV29FR#5FuAfSzxhH6h) (RedHat/Fedora x86_64)
       
  * **`Windows downloads (Shared):`**
  
    * [ffmpeg-6.1-win-64bit-build.zip](https://drive.proton.me/urls/FZH7FV29FR#5FuAfSzxhH6h)
    * [ffmpeg-6.1-win-64bit-build.exe](https://drive.proton.me/urls/FZH7FV29FR#5FuAfSzxhH6h)
    * [ffmpeg-6.1-cygwin-64bit-build.tar.gz](https://drive.proton.me/urls/FZH7FV29FR#5FuAfSzxhH6h)

### HOW TO INSTALL:

  * **GNU/Linux instructions:**

    * Download the package [ffmpeg-6.1-linux-gnu-64bit-build.tar.bz2](https://drive.proton.me/urls/FZH7FV29FR#5FuAfSzxhH6h).
    * Open the terminal and type the following command for install:
        * `$ sudo tar jxvf ffmpeg-6.1-linux-gnu-64bit-build.tar.bz2 -C /`
    
  * **Windows instructions:**
    
    * Download the package [ffmpeg-6.1-win-64bit-build.zip](https://drive.proton.me/urls/FZH7FV29FR#5FuAfSzxhH6h).
    * Unzip the package with [7-zip](http://www.7-zip.org/) or [Winrar](http://www.rarlab.com/).
    * Copy the files to a folder. For example: `C:\Program Files\FFmpeg`
    * Add the path `C:\Program Files\FFmpeg` to [PATH](https://www.google.es/search?q=add+folder+to+PATH+on+Windows) variable.

  * **Cygwin instructions:**
    
    * Download the package [ffmpeg-6.1-cygwin-64bit-build.tar.gz](https://drive.proton.me/urls/FZH7FV29FR#5FuAfSzxhH6h).
    * Open the Cygwin terminal and type the following command for install:
        * `$ tar jxvf ffmpeg-6.1-cygwin-64bit-build.tar.gz -C /`   
 
### HOW TO CREATE YOUR BUILD:

  * **GNU/Linux instructions:**
  
    * Install dependencies in your GNU/Linux distro.
    * Dependencies: `wget`, `gcc`, `make`, `cmake`, `meson/ninja` and `git`.
    * Type the following commands:
        * `$ git clone https://gitlab.com/q3aql/ffmpeg-builds`
        * `$ cd ffmpeg-builds`
        * `$ sudo ./ffmpeg-static-build-[arch].sh`
    
    _Note: Replace `[arch]` with `linux32` or `linux64` depending on your architecture._
      
  * **Windows instructions:**
  
    * Install Cygwin for [32bits](https://cygwin.com/setup-x86.exe) or [64bits](https://cygwin.com/setup-x86_64.exe).
    * During installation, `configure the repository` and install `git` and `wget` or `lynx`.
    * Open Cygwin terminal and type the following commands:
        * `$ git clone https://gitlab.com/q3aql/ffmpeg-builds`
        * `$ cd ffmpeg-builds`
        * `$ ./ffmpeg-share-build-[arch].sh`
    
    _Note: Replace `[arch]` with `cygwin32` or `cygwin64` depending on your architecture._

### Related links:

  * [FFmpeg homepage](https://ffmpeg.org/)
  * [FFmpeg Linux builds by John](https://johnvansickle.com/ffmpeg/)
  * [FFmpeg Win64/Linux64 Builds by Btbn](https://github.com/BtbN/FFmpeg-Builds)
  * [FFmpeg Win32 Builds](https://github.com/sudo-nautilus/FFmpeg-Builds-Win32)
